import { select, scaleOrdinal, schemeSpectral } from 'd3';
import { loadAndProcessData } from './loadAndProcessData.js';
import { colorLegend } from './colorLegend';
import { chloropethMap } from './chloropethMap';

const svg = select('svg');

const chloroplethMapG = svg.append('g');
const colorLegendG = svg.append('g')
	.attr('tansform', `translate(500, 100)`);

const colorScale = scaleOrdinal();
const colorValue = d => d.properties.economy;

let selectedColorValue;
let features;

const onClick = d => {
	selectedColorValue = d;
	render();
};

loadAndProcessData().then(countries => {
  features = countries.features;
  render();
});

const render = () => {
  	colorScale
      .domain(features.map(colorValue))
      .domain(colorScale.domain().sort().reverse())
  		.range(schemeSpectral[colorScale.domain().length]);
  
  	colorLegendG
      .call(colorLegend, {
      colorScale,
      circleRadius : 10,
      spacing : 30,
      textOffset : 20,
      backgroundRectWidth: 250,
      onClick,
      selectedColorValue
		});
  
  	chloroplethMapG.call(chloropethMap, {
    	features,
      colorScale, 
      colorValue,
      selectedColorValue
    })
  
}
